
# q-expansion of newform 1242.2.e.b, downloaded from the LMFDB on 01 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1242
weight = 2
poly_data = [9, -21, 64, -1, 64, -19, 34, -4, 7, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[37125, -1485, 4356, 6253, 3531, -1947, 95, -429, 132, -134], 14559], [[-9081, -194145, -41986, -65255, -20431, -34543, -4688, -4321, -537, -999], 72795], [[29709, -15165, 44484, -51145, 36059, -19883, 7882, -4381, 1348, -339], 24265], [[291084, -98415, 288684, -348400, 234009, -129033, 47767, -28431, 8748, -2704], 72795], [[-18639, -166780, -72109, -175205, 42836, -104352, 8823, -21759, 2962, -3301], 72795], [[194139, -82890, 243144, -177740, 197094, -108678, 42362, -23946, 7368, -3509], 72795], [[-40662, -387390, -183672, -304890, -67267, -164966, -15316, -32647, -1154, -4858], 72795], [[43308, 650705, 179673, 371520, -11527, 213629, -4601, 41313, -3379, 6592], 72795], [[-132759, 412380, 188016, 450205, -92449, 293173, -18587, 60896, -7538, 9564], 72795]]

hecke_ring_character_values = [[461, [0, 0, 0, 0, 0, 1, 0, 0, 0, 0]], [649, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[-1, 0, 0, 0, 0, -1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [1, 0, 1, 1, 0, 1, -1, -1, 0, 0], [2, 0, 0, 0, -1, 2, 1, 1, 1, 0], [0, -1, 0, 0, 0, -2, 0, -1, 1, -1], [0, -2, 0, 0, 0, 0, -1, 0, 0, 0], [-1, 1, 0, -2, 0, 0, 1, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 0], [1, 0, -2, -2, 1, 1, -1, -1, -1, -2], [0, -1, -2, 0, 0, -2, 0, -1, 1, -1], [-2, 0, 0, 1, 2, 0, -1, 0, 0, 0], [0, 0, -1, 0, 0, -5, 0, -2, -1, 0], [5, 0, -1, -1, 1, 5, -2, -2, -1, -1], [3, 0, 2, 2, 0, 3, 0, 0, 0, 4], [3, 1, 0, 2, 0, 0, 1, 0, 0, 0], [0, 1, 3, 0, 0, -2, 0, -1, 2, 1], [0, 0, 1, 1, -1, 0, -3, -3, 1, 1], [0, 0, -1, 0, 0, -1, 0, 1, 0, 0], [-5, 2, 0, 1, 1, 0, 1, 0, 0, 0], [3, 0, 0, -2, 1, 0, -2, 0, 0, 0], [-4, 0, -1, -1, -2, -4, -2, -2, 2, -2], [5, 0, 1, 1, -1, 5, 3, 3, 1, 0], [-9, 3, 0, -2, 0, 0, -1, 0, 0, 0], [5, 0, -2, -2, 1, 5, -1, -1, -1, -2], [4, 0, -1, -1, -2, 4, -1, -1, 2, 0], [0, -1, 1, 0, 0, -5, 0, 4, -2, -1], [6, -3, 0, 1, 0, 0, 1, 0, 0, 0], [1, 3, 0, 2, -1, 0, 3, 0, 0, 0], [0, 2, -1, 0, 0, -2, 0, -3, -1, 2], [2, 1, 0, 1, 0, 0, -2, 0, 0, 0], [0, -1, -3, 0, 0, -2, 0, 4, -1, -1], [6, 0, 1, 1, 0, 6, -3, -3, 0, 2], [0, 2, 4, 0, 0, 4, 0, 3, 1, 2], [0, 0, 2, 0, 0, -1, 0, 0, 4, 0], [0, 0, -1, -1, 2, 0, -1, -1, -2, 1], [0, -4, 0, 0, 0, -4, 0, 0, 0, -4], [3, -3, 0, 1, 1, 0, 6, 0, 0, 0], [0, 4, 2, 0, 0, 5, 0, -2, 1, 4], [-3, 0, -2, -2, 0, -3, -4, -4, 0, 0], [-6, -1, 0, 2, 0, 0, -1, 0, 0, 0], [-1, 1, 0, 1, -3, 0, -4, 0, 0, 0], [-6, 0, 0, 0, 0, -6, 6, 6, 0, 1], [0, 1, 3, 0, 0, 7, 0, 5, 1, 1], [1, -3, 0, -2, 1, 0, 2, 0, 0, 0], [-1, -2, 0, 3, 0, 0, 4, 0, 0, 0], [0, 1, -1, 0, 0, 4, 0, 4, -2, 1], [2, 0, 2, 2, 1, 2, 2, 2, -1, -4], [4, 0, 1, 1, 1, 4, 5, 5, -1, 3], [0, 0, 4, 0, 0, -1, 0, -1, 3, 0], [0, -1, 0, 1, 3, 0, -5, 0, 0, 0], [0, -5, -6, 0, 0, -4, 0, -7, -2, -5], [2, 0, 2, 2, -5, 2, 7, 7, 5, 5], [-8, -4, 0, -3, 1, 0, -2, 0, 0, 0], [0, 0, -3, 0, 0, 0, 0, -5, 3, 0], [2, 0, -3, -3, 2, 2, 4, 4, -2, -6], [9, 3, 0, -6, 0, 0, 1, 0, 0, 0], [5, -4, 0, 4, -3, 0, 1, 0, 0, 0], [-2, 0, -3, -3, 3, -2, 3, 3, -3, 5], [7, 0, 7, 7, 1, 7, 6, 6, -1, 2], [0, 2, 4, 0, 0, -3, 0, -2, -1, 2], [0, -1, 3, 0, 0, -4, 0, -1, 1, -1], [-11, 6, 0, -3, -4, 0, 0, 0, 0, 0], [0, 6, 2, 0, 0, 6, 0, 3, 0, 6], [-6, 0, 4, 4, -4, -6, 1, 1, 4, 3], [2, 0, -5, -5, -1, 2, 7, 7, 1, -4], [-5, 0, 0, 0, -3, -5, 4, 4, 3, -1], [0, -5, -4, 0, 0, 0, 0, 4, -4, -5], [0, 1, 3, 0, 0, 13, 0, 1, -4, 1], [-11, 0, 2, 2, 0, -11, 0, 0, 0, -5], [7, 0, 3, 3, -2, 7, -2, -2, 2, 3], [-9, -7, 0, 2, -6, 0, 6, 0, 0, 0], [18, 0, -2, -2, -1, 18, 5, 5, 1, 1], [0, -2, -10, 0, 0, 5, 0, 0, 0, -2], [-9, 2, 0, -3, -2, 0, -6, 0, 0, 0], [0, -5, -9, 0, 0, 8, 0, 5, -2, -5], [6, 0, 0, 0, -3, 6, 2, 2, 3, 1], [8, -2, 0, -1, 0, 0, -4, 0, 0, 0], [0, 6, 6, 0, 0, -8, 0, 3, 2, 6], [0, -3, 6, 0, 0, 15, 0, 1, -1, -3], [0, -3, -5, 0, 0, -12, 0, -4, 0, -3], [-10, 0, -10, -10, -2, -10, -1, -1, 2, -5], [4, -1, 0, -7, 1, 0, 3, 0, 0, 0], [16, 2, 0, -6, -1, 0, 0, 0, 0, 0], [6, 0, -6, -6, 5, 6, 0, 0, -5, -6], [-10, 0, 5, 5, -4, -10, -4, -4, 4, 3], [8, 3, 0, -2, 5, 0, -2, 0, 0, 0], [-9, 0, 2, 2, -4, -9, -2, -2, 4, 3], [0, 0, 6, 6, 3, 0, -2, -2, -3, -1], [0, -2, 4, 0, 0, 8, 0, 8, 0, -2], [1, 1, 0, 9, -2, 0, -1, 0, 0, 0], [18, 0, 1, 1, 6, 18, 1, 1, -6, 6], [3, -5, 0, 4, -5, 0, 4, 0, 0, 0], [0, 8, 2, 0, 0, 3, 0, 5, 3, 8], [0, 0, -5, 0, 0, -6, 0, -6, 2, 0], [1, 0, 0, 8, -5, 0, -5, 0, 0, 0], [0, 5, 4, 0, 0, -2, 0, 3, 5, 5], [-11, 2, 0, -14, -5, 0, 3, 0, 0, 0], [-9, -4, 0, -1, 4, 0, 3, 0, 0, 0], [2, 7, 0, 2, -3, 0, -8, 0, 0, 0], [18, 0, 4, 4, 2, 18, 9, 9, -2, 3], [7, 4, 0, -2, 1, 0, 4, 0, 0, 0], [0, 6, 9, 0, 0, -5, 0, 4, 2, 6], [-6, 0, 1, 1, 0, -6, -9, -9, 0, -6], [0, 4, 2, 0, 0, 19, 0, 6, 4, 4], [-9, 1, 0, -4, 7, 0, 10, 0, 0, 0], [-2, 0, 4, 4, -5, -2, -2, -2, 5, 5], [7, -3, 0, 0, -2, 0, -6, 0, 0, 0], [0, 2, -3, 0, 0, -7, 0, 5, 4, 2], [-19, 0, -4, -4, -2, -19, -4, -4, 2, 1], [0, -7, -1, 0, 0, -9, 0, 2, -7, -7], [3, 6, 0, 4, -2, 0, 5, 0, 0, 0], [0, -4, -5, 0, 0, -2, 0, -15, -1, -4], [1, 0, 3, 3, 0, 1, -5, -5, 0, 7], [-2, 5, 0, -6, -1, 0, 8, 0, 0, 0], [-7, 0, 7, 7, -7, -7, -2, -2, 7, -7], [0, -2, 2, 0, 0, -19, 0, -8, 3, -2], [-17, 8, 0, -11, 1, 0, -3, 0, 0, 0], [0, 5, 3, 0, 0, 5, 0, -5, -5, 5], [-16, 0, 0, 0, -1, -16, 0, 0, 1, -6], [0, -3, 0, 0, 0, -2, 0, -10, 4, -3], [-12, 0, -4, -4, -1, -12, 4, 4, 1, -13], [-10, 0, 5, 5, -4, -10, -3, -3, 4, 7], [16, -7, 0, 7, -2, 0, -5, 0, 0, 0], [0, 0, 1, 1, -4, 0, 3, 3, 4, -7], [12, -2, 0, 10, 6, 0, -3, 0, 0, 0], [10, 0, 6, 6, 0, 10, -3, -3, 0, 3], [19, 0, 0, 7, 4, 0, -4, 0, 0, 0], [-16, 0, -5, -5, 7, -16, 2, 2, -7, -5], [0, 7, 15, 0, 0, -3, 0, 3, 2, 7], [-4, -4, 0, 5, -6, 0, -8, 0, 0, 0], [0, -10, -6, 0, 0, 14, 0, 1, -2, -10], [0, 4, 6, 0, 0, -20, 0, -2, 1, 4], [-14, -10, 0, 11, -4, 0, -4, 0, 0, 0], [0, -6, -5, 0, 0, -10, 0, -4, -2, -6], [0, 3, 3, 0, 0, 9, 0, 16, 2, 3], [2, -7, 0, 0, 2, 0, 10, 0, 0, 0], [0, -1, -1, 0, 0, -18, 0, -11, -4, -1], [0, 1, -4, 0, 0, 11, 0, 2, -5, 1], [24, 4, 0, -9, 3, 0, -2, 0, 0, 0], [-2, 5, 0, 6, 5, 0, -4, 0, 0, 0], [4, 0, 6, 6, -8, 4, 11, 11, 8, 7], [0, 13, 2, 0, 0, -9, 0, -7, -1, 13], [7, 3, 0, 4, -8, 0, -4, 0, 0, 0], [8, 5, 0, -8, -3, 0, 9, 0, 0, 0], [1, 0, -6, -6, -5, 1, 0, 0, 5, -6], [21, 0, 0, 0, 5, 21, -1, -1, -5, 3], [-11, 0, 3, 3, 4, -11, -1, -1, -4, -2], [0, 7, 13, 0, 0, -1, 0, 11, 3, 7], [24, 0, 0, 1, -3, 0, 0, 0, 0, 0], [0, 7, -2, 0, 0, -9, 0, 3, 2, 7], [-7, -7, 0, 5, -1, 0, 6, 0, 0, 0], [17, 2, 0, -2, -3, 0, -9, 0, 0, 0], [0, -2, -3, 0, 0, 8, 0, 2, -11, -2], [-7, 0, 1, 1, 7, -7, 11, 11, -7, 2], [16, 0, -4, -4, 10, 16, 7, 7, -10, 7], [-16, 0, 0, -4, 3, 0, 10, 0, 0, 0], [19, 0, 0, 0, -2, 19, 2, 2, 2, -5], [38, 1, 0, 2, 0, 0, -3, 0, 0, 0], [0, -4, -3, 0, 0, -2, 0, 7, -4, -4], [-17, 0, 0, 0, -8, -17, 4, 4, 8, -1], [5, 5, 0, 6, -4, 0, 12, 0, 0, 0], [0, -2, -4, 0, 0, 0, 0, -3, -4, -2], [-8, 6, 0, -2, 1, 0, 9, 0, 0, 0], [0, 6, -5, 0, 0, -2, 0, -4, -4, 6], [28, 0, 2, 2, 7, 28, 4, 4, -7, 9], [0, 6, 0, -6, 7, 0, 10, 0, 0, 0], [-9, 0, 2, 2, -7, -9, -2, -2, 7, -7], [-4, -1, 0, -8, 0, 0, 2, 0, 0, 0], [0, -4, 0, 0, 0, -23, 0, 0, -10, -4], [-1, 0, -9, -9, 8, -1, 4, 4, -8, 1], [0, -3, -6, 0, 0, 16, 0, -11, -5, -3], [0, -3, -5, 0, 0, 29, 0, 7, -2, -3], [-3, 0, -3, -3, -1, -3, -1, -1, 1, -6], [0, 10, 2, 0, 0, -11, 0, 6, 7, 10], [0, -14, -8, 0, 0, -17, 0, -2, 2, -14], [3, 0, 1, 1, -1, 3, 0, 0, 1, 5], [-31, 6, 0, -10, -4, 0, -5, 0, 0, 0], [-15, 9, 0, -9, 1, 0, 6, 0, 0, 0], [24, 0, -7, -7, 2, 24, 6, 6, -2, 1], [2, 0, -1, -1, 4, 2, -8, -8, -4, -3], [11, 0, 4, 4, 2, 11, -4, -4, -2, 7], [0, 5, -8, 0, 0, -4, 0, 10, -3, 5], [7, 1, 0, -16, 1, 0, 5, 0, 0, 0], [0, 4, 2, 0, 0, -3, 0, 8, -6, 4], [4, 0, -10, -10, 7, 4, -3, -3, -7, -14], [-6, -1, 0, 5, -2, 0, 0, 0, 0, 0], [22, 0, -12, -12, 6, 22, -7, -7, -6, -4], [0, 1, -11, 0, 0, -18, 0, -11, 2, 1], [-18, 4, 0, -6, 3, 0, -4, 0, 0, 0], [-2, 2, 0, 4, -10, 0, -5, 0, 0, 0], [-5, 0, -13, -13, 1, -5, -6, -6, -1, -10], [-29, 5, 0, -1, -4, 0, 0, 0, 0, 0], [-3, 0, 3, 3, -3, -3, -9, -9, 3, -4], [-5, 7, 0, 12, -5, 0, 8, 0, 0, 0], [0, -9, -3, 0, 0, -10, 0, 0, 10, -9], [0, -16, -11, 0, 0, -8, 0, 3, -5, -16], [13, 0, -1, -1, 0, 13, -10, -10, 0, -1], [-3, 0, 13, 13, -6, -3, 7, 7, 6, 11], [1, -13, 0, 20, -2, 0, -14, 0, 0, 0], [0, 9, 8, 0, 0, 19, 0, -2, 8, 9], [-2, 0, 8, 8, 0, -2, -5, -5, 0, 13], [0, -6, 11, 0, 0, -13, 0, 1, 6, -6], [-3, 0, 5, 5, 11, -3, 8, 8, -11, 2], [-19, 4, 0, -8, 2, 0, 6, 0, 0, 0], [11, -4, 0, 0, -4, 0, 0, 0, 0, 0], [-12, -1, 0, -10, 4, 0, -6, 0, 0, 0], [0, 8, 7, 0, 0, 0, 0, 13, 0, 8], [25, 0, 8, 8, -5, 25, -6, -6, 5, 1], [0, 8, -2, 0, 0, -6, 0, 18, -4, 8], [-2, -5, 0, 4, 5, 0, 2, 0, 0, 0], [0, 10, -4, 0, 0, -13, 0, 1, 7, 10], [25, 0, 5, 5, 6, 25, 11, 11, -6, 7], [21, 0, -7, -7, -3, 21, 12, 12, 3, -1], [0, -8, -4, 0, 0, -46, 0, -5, 7, -8], [-20, 0, 2, 2, -9, -20, 12, 12, 9, 14], [0, 4, -11, 0, 0, -8, 0, -1, -5, 4], [7, 0, -7, -7, 7, 7, 1, 1, -7, -9], [-9, -7, 0, 4, 0, 0, 4, 0, 0, 0], [0, -1, -8, 0, 0, 19, 0, -3, -1, -1], [0, 4, -2, 0, 0, 43, 0, -6, -2, 4], [0, -3, -7, 0, 0, 8, 0, -19, 0, -3], [0, 1, -10, 0, 0, -3, 0, 18, -9, 1], [15, -12, 0, 2, 4, 0, -6, 0, 0, 0], [0, 6, -1, 0, 0, -14, 0, -5, -4, 6], [-1, 0, 16, 16, -2, -1, 0, 0, 2, 9], [7, 0, -1, -1, -2, 7, 2, 2, 2, 15], [-25, 4, 0, -1, 5, 0, 11, 0, 0, 0], [24, 0, -2, -2, -1, 24, -2, -2, 1, -5], [5, 0, -14, -14, -4, 5, 8, 8, 4, 1], [0, 0, -12, 0, 0, -7, 0, 21, -3, 0], [-22, -5, 0, -1, -3, 0, -10, 0, 0, 0], [0, 2, 1, 0, 0, -19, 0, -11, -6, 2], [0, 7, 12, 0, 0, 21, 0, 7, 3, 7], [9, 0, -6, -6, -7, 9, -10, -10, 7, 3], [-17, 0, -13, -13, 4, -17, 9, 9, -4, -5], [0, -4, 10, 0, 0, 3, 0, 13, -1, -4], [-30, -3, 0, 6, -6, 0, 10, 0, 0, 0], [0, 7, 16, 0, 0, -4, 0, -16, -2, 7], [-16, 2, 0, 4, 8, 0, -6, 0, 0, 0], [11, 0, 13, 13, 5, 11, 0, 0, -5, 4], [21, 7, 0, 5, -2, 0, -4, 0, 0, 0], [0, -11, 12, 0, 0, 4, 0, -3, 7, -11], [-6, 8, 0, 6, 4, 0, 0, 0, 0, 0], [0, -5, 9, 0, 0, 16, 0, 8, 2, -5], [1, 0, 3, 3, -11, 1, 5, 5, 11, 1], [-7, 0, 0, -1, 3, 0, -17, 0, 0, 0], [0, 0, -1, 0, 0, 8, 0, -1, -5, 0], [0, 6, 5, 0, 0, -10, 0, -7, -6, 6], [-10, 5, 0, -3, 5, 0, 8, 0, 0, 0], [0, -1, 1, 0, 0, 17, 0, 5, 0, -1], [-33, 1, 0, 0, 3, 0, -22, 0, 0, 0], [0, 12, 4, 0, 0, -3, 0, -7, 9, 12], [45, 0, -6, -6, -1, 45, 0, 0, 1, -1], [16, 0, -9, -9, 4, 16, 10, 10, -4, 2], [-13, 9, 0, -2, -7, 0, -3, 0, 0, 0], [-17, -6, 0, -3, -10, 0, 12, 0, 0, 0], [-27, 0, 12, 12, -10, -27, 5, 5, 10, 0], [-15, 2, 0, -9, -3, 0, -2, 0, 0, 0], [42, 1, 0, 2, 7, 0, -1, 0, 0, 0], [-5, 0, -7, -7, 0, -5, -10, -10, 0, 2], [-1, 0, 21, 21, -4, -1, -12, -12, 4, 3], [0, 0, 18, 0, 0, 2, 0, 0, -9, 0], [9, -3, 0, -18, 4, 0, 3, 0, 0, 0], [0, -19, -5, 0, 0, -17, 0, 6, 2, -19], [16, 0, 13, 13, -3, 16, -15, -15, 3, -6], [22, -11, 0, 6, 4, 0, 12, 0, 0, 0], [17, 0, 8, 8, 5, 17, 10, 10, -5, 1], [0, -1, -1, 0, 0, -9, 0, -3, 2, -1], [0, 7, 3, 0, 0, -2, 0, 19, 8, 7], [0, 1, 16, 0, 0, -15, 0, 11, 5, 1], [-20, 15, 0, -10, 5, 0, -5, 0, 0, 0], [-27, 0, 2, 2, 11, -27, 1, 1, -11, 1], [0, 0, -14, 0, 0, -27, 0, -5, -4, 0], [0, 6, -4, 0, 0, 5, 0, -6, 9, 6], [22, 5, 0, 1, -1, 0, 6, 0, 0, 0], [0, -9, -5, 0, 0, -17, 0, -7, 11, -9], [8, 0, -8, -8, -2, 8, 5, 5, 2, -15], [38, 0, 0, -7, 0, 0, 12, 0, 0, 0], [0, 0, 2, 2, 3, 0, -5, -5, -3, -3], [0, -6, 1, 0, 0, 8, 0, -19, -5, -6], [0, -5, -1, 0, 0, -3, 0, 18, -4, -5], [0, 0, 16, 16, -3, 0, 7, 7, 3, 1], [30, 0, 3, 3, -1, 30, 24, 24, 1, 8], [0, 0, -7, 0, 0, -17, 0, 12, 7, 0], [-15, 9, 0, 9, -3, 0, 0, 0, 0, 0], [25, 5, 0, 11, -4, 0, -12, 0, 0, 0], [0, 14, 2, 0, 0, 4, 0, 7, -7, 14], [18, 0, -1, -1, 5, 18, 0, 0, -5, -14], [14, 6, 0, -5, -1, 0, -16, 0, 0, 0], [5, 0, -23, -23, 2, 5, 7, 7, -2, -7], [16, 6, 0, -6, 1, 0, -15, 0, 0, 0], [0, 6, -4, 0, 0, -14, 0, 16, -4, 6], [0, -6, -2, 0, 0, -5, 0, 23, -4, -6], [-9, 0, -7, -7, 8, -9, -6, -6, -8, -14], [0, -5, -15, 0, 0, -36, 0, 2, 3, -5], [8, 0, 16, 16, -2, 8, -12, -12, 2, 1], [25, 0, -3, -3, 7, 25, 7, 7, -7, -7], [-14, 0, 0, -1, 1, 0, -26, 0, 0, 0], [-12, 0, 4, 4, 5, -12, -18, -18, -5, 3], [0, -2, 1, 0, 0, -21, 0, -3, 8, -2], [-7, -17, 0, 2, 5, 0, -4, 0, 0, 0], [-17, 5, 0, 5, 8, 0, 4, 0, 0, 0]]
